@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 5.12 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2015, Mark Calabretta
+  WCSLIB 7.2 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,10 +22,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: prj.h,v 5.12 2015/11/15 02:13:00 mcalabre Exp $
+  $Id: prj.h,v 7.2 2020/03/09 07:31:23 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 5.12 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.2 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -154,6 +154,11 @@
 * prjini() sets all members of a prjprm struct to default values.  It should
 * be used to initialize every prjprm struct.
 *
+* PLEASE NOTE: If the prjprm struct has already been initialized, then before
+* reinitializing, it prjfree() should be used to free any memory that may have
+* been allocated to store an error message.  A memory leak may otherwise
+* result.
+*
 * Returned:
 *   prj       struct prjprm*
 *                       Projection parameters.
@@ -712,8 +717,8 @@ int prjini(struct prjprm *prj);
 int prjfree(struct prjprm *prj);
 int prjprt(const struct prjprm *prj);
 int prjperr(const struct prjprm *prj, const char *prefix);
-int prjbchk(double tol, int nx, int ny, int spt, double phi[], double theta[],
-           int stat[]);
+int prjbchk(double tol, int nphi, int ntheta, int spt, double phi[],
+            double theta[], int stat[]);
 
 int prjset(struct prjprm *prj);
 int prjx2s(PRJX2S_ARGS);
